# Generated by Django 5.2.11 on 2026-02-10 16:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('geo_lib', '0005_alter_geoelement_filterable_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='geofeature',
            options={'ordering': ('indicator', 'name'), 'verbose_name': 'Données de la carte', 'verbose_name_plural': 'Données de la carte'},
        ),
    ]
