# Generated by Django 5.2.11 on 2026-02-10 16:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('indicators_lib', '0007_remove_subtheme_description_alter_filter_color_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='indicator',
            name='min_mesh',
            field=models.TextField(choices=[('fr', 'Fr'), ('reg', 'Reg'), ('dep', 'Dep'), ('epci', 'Epci'), ('com', 'Com'), ('aom', 'Aom'), ('ept', 'Ept')], default='com'),
        ),
    ]
