{% extends "territories_dashboard_lib/website/layout/base.html" %}
{% load static %}
{% block page_title %}Lexique{% endblock %}


{% block css %}
    {% include "territories_dashboard_lib/website/pages/lexique/page.css" %}
{% endblock %}


{% block main %}
<main role="main" class="fr-container glossary fr-pt-md-8w fr-pb-md-10w fr-pt-4w fr-pb-6w" id="contenu" tabindex="-1">
    <h1>Lexique</h1> 
    <dl class="definitions">
        {% for item in lexique %}
        <div>
            <dt><strong>{{ item.word }}</strong></dt>
            <dd>{{ item.definition }}</dd>
        </div>
        {% endfor %}
    </dl>
</main>
{% endblock %}
