/* === Boutons et éléments interactifs === */
.tdbmd-indicator-btn {
    background: var(--grey-1000-100);
    border: 1px solid var(--border-default-grey);
    box-shadow: none;
    width: 100%;
    display: inline-flex;
    font-size: 1rem;
    line-height: 1.5rem;
    min-height: 3rem;
    position: relative;
}

.tdbmd-indicator-btn::after {
    right: 1rem;
    position: absolute;
}

/* === Accordéons === */
.tdbmd-indicator-accordion {
    background: var(--grey-1000-100);
    border-left: 1px solid var(--border-default-grey);
    border-right: 1px solid var(--border-default-grey);
}

.tdbmd-indicator-accordion::before {
    box-shadow: none;
}

.tdbmd-indicator-accordion-comparison {
    border-bottom: 1px solid var(--border-default-grey);
}

/* === Cartes d'indicateurs === */
.tdbmd-indicator-card__data-container {
    color: var(--text-action-high-blue-france);
}

.tdbmd-indicator-card__data-number {
    font-size: 30px;
    line-height: 1.2;
    font-weight: 700;
}

/* === Comparaison - Valeurs principales === */
.comparison-main-values {
    display: flex;
    flex-direction: row;
    gap: 32px;
    flex-wrap: wrap;
    align-items: baseline;
}

/* === Autres styles === */
.border-top {
    border-top: 1px solid var(--border-default-grey);
}
