<footer role="contentinfo" id="page-footer">
    {% if view_name != "website:superset" and main_conf.show_footer_contact_banner and main_conf.newsletter_link and main_conf.contact_email %}
        <div class="fr-follow fr-pt-8w">
            <h2 class="fr-sr-only">Contact</h2>
            <div class="fr-container">
                <div class="fr-grid-row">
                    <div class="fr-col-12 fr-col-md-6">
                        <div class="fr-follow__newsletter">
                            <div>
                                <h3 class="fr-h5 fr-follow__title">Une question ? Écrivez-nous !</h3>
                                <p>Vous avez une question ou vous souhaitez nous faire part de vos retours, écrivez-nous ! L'équipe projet vous répondra dans les meilleurs délais.</p>
                                <ul class="fr-btns-group fr-btns-group--equisized fr-btns-group--left fr-btns-group--icon-left">
                                    <li>
                                        <a href="mailto:tableau-de-bord-mobilites-durables@developpement-durable.gouv.fr" aria-label="Nous contacter par email - nouvelle fenêtre email" target="_blank" class="fr-btn fr-icon-mail-line fr-btn--icon-left">Nous contacter</a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <div class="fr-col-12 fr-col-md-6">
                        <div class="fr-follow__newsletter">
                            <div>
                                <h3 class="fr-h5">Restez informé.e de l'actualité du {{ main_conf.title }}</h3>
                                <p class="fr-text--sm">Pour recevoir des informations sur les nouveautés et prochains événements du {{ main_conf.title }}, laissez nous vos coordonnées en remplissant le formulaire suivant</p>
                                <ul class="fr-btns-group fr-btns-group--equisized fr-btns-group--left fr-btns-group--icon-left">
                                    <li>
                                        <a href="https://grist.numerique.gouv.fr/o/pnc-mobilite-durable/forms/c4vDkemSd6x34wEz6M87zx/4" aria-label="Formulaire d'inscription - nouvelle fenêtre" target="_blank" class="fr-btn fr-icon-links-line fr-btn--icon-left">Formulaire d'inscription</a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    {% endif %}
    <div class="fr-footer">
        <div class="fr-container">
            <div class="fr-footer__body">
                <div class="fr-footer__brand fr-enlarge-link">
                    <a href="/" title="Accueil - {{ main_conf.title }} du {{ main_conf.entity }}">
                        <p class="fr-logo">
                            {{ main_conf.entity_breaklines|safe }}
                        </p>
                    </a>
                </div>
                <div class="fr-footer__content">
                    <ul class="fr-footer__content-list">
                        <li class="fr-footer__content-item">
                            <a class="fr-footer__content-link" target="_blank" rel="noopener external" title="info.gouv.fr - nouvelle fenêtre" href="https://info.gouv.fr">info.gouv.fr</a>
                        </li>
                        <li class="fr-footer__content-item">
                            <a class="fr-footer__content-link" target="_blank" rel="noopener external" title="service-public.fr - nouvelle fenêtre" href="https://service-public.fr">service-public.fr</a>
                        </li>
                        <li class="fr-footer__content-item">
                            <a class="fr-footer__content-link" target="_blank" rel="noopener external" title="legifrance.gouv.fr - nouvelle fenêtre" href="https://legifrance.gouv.fr">legifrance.gouv.fr</a>
                        </li>
                        <li class="fr-footer__content-item">
                            <a class="fr-footer__content-link" target="_blank" rel="noopener external" title="data.gouv.fr - nouvelle fenêtre" href="https://data.gouv.fr">data.gouv.fr</a>
                        </li>
                    </ul>
                </div>
            </div>
            <div class="fr-footer__bottom">
                <ul class="fr-footer__bottom-list">
                    <li class="fr-footer__bottom-item">
                        <a href="/journal/" class="fr-footer__bottom-link">
                            Version {{ version }}
                        </a>
                    </li>
                    {% for link in main_conf.parsed_footer_navigation %}
                        <li class="fr-footer__bottom-item">
                            {% if link.is_external %}
                                <a href="{{ link.href }}"
                                target="_blank"
                                rel="noopener noreferrer"
                                class="fr-footer__bottom-link"
                                title="{{ link.title }} - nouvelle fenêtre">
                                    {{ link.title }}
                                </a>
                            {% else %}
                                <a href="{{ link.href }}" class="fr-footer__bottom-link">
                                    {{ link.title }}
                                </a>
                            {% endif %}
                        </li>
                    {% endfor %}
                </ul>
                <div class="fr-footer__bottom-copy">
                <p>Sauf mention explicite de propriété intellectuelle détenue par des tiers, les contenus de ce site sont proposés sous <a href="https://github.com/etalab/licence-ouverte/blob/master/LO.md" target="_blank" rel="noopener external" title="Licence etalab - nouvelle fenêtre">licence etalab-2.0</a>
                </p>
                </div>
            </div>
        </div>
    </div>
</footer>
