# Generated by Django 5.2.10 on 2026-01-19 13:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tracking_lib', '0006_alter_event_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='name',
            field=models.TextField(choices=[('download', 'Download'), ('vue-resume-indicateur', 'View Indicator Card'), ('attention-sur-resume-indicateur', 'Attention On Indicator Card')]),
        ),
    ]
