.chart-buttons {
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
    align-items: center;
    gap: 2rem;
    padding: 2rem;
}

.chart-buttons label::before {
    margin-right: 0.5rem;
}

.checkbox-label {
    text-wrap: nowrap;
}
