{% extends "admin/base_site.html" %}

{% load static %}

{% block extrastyle %}
    <style>
        {% include "./override.css" %}
        {% if ENVIRONMENT == "ppd" %}
            {% include "./purple_theme.css" %}
        {% elif ENVIRONMENT == "ppd-beta" %}
            {% include "./green_theme.css" %}
        {% elif ENVIRONMENT == "prd" %}
            {% include "./red_theme.css" %}
        {% endif %}
    </style>
{% endblock %}

{% block branding %}
    <div id="site-name">
        <a href="{% url 'admin:index' %}">
            <div>
                <img src="{% static 'territories_dashboard_lib/website/images/marianne.png' %}"/>
                {{ main_conf.title }}
                {% if ENVIRONMENT == "ppd" %}
                    | PREPROD
                {% elif ENVIRONMENT == "ppd-beta" %}
                    | BETA
                {% elif ENVIRONMENT == "prd" %}
                    | PRODUCTION
                {% endif %}
            </div>
        </a>
    </div>
    {% if user.is_anonymous %}
    {% include "admin/color_theme_toggle.html" %}
    {% endif %}
{% endblock %}