# Generated by Django 5.2.9 on 2026-01-06 16:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geo_lib', '0002_geoelement_linked_to_indicator'),
    ]

    operations = [
        migrations.AddField(
            model_name='geofeature',
            name='color_column',
            field=models.TextField(blank=True, help_text="Optionnel. Nom de la colonne qui définit une couleur par point. Les valeurs de la colonne doivent être sous le format #ffffff (hexadecimale). Si renseigné, le champ 'color' ne sera pas utilisé. Seulement pour les points.", null=True, verbose_name='Colonne de la couleur'),
        ),
        migrations.AddField(
            model_name='geofeature',
            name='size_column',
            field=models.TextField(blank=True, help_text="Optionnel. Nom de la colonne qui définit une taille par point. Les valeurs de la colonne doivent être 'sm' (small) ou 'md' (medium). Seulement pour les points.", null=True, verbose_name='Colonne de la taille'),
        ),
    ]
