# Generated by Django 5.2.8 on 2025-12-03 13:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('superset_lib', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='filter',
            name='mesh',
            field=models.TextField(blank=True, choices=[('fr', 'Fr'), ('reg', 'Reg'), ('dep', 'Dep'), ('epci', 'Epci'), ('com', 'Com'), ('aom', 'Aom')], help_text="Maille du territoire sur lequel s'effectue le filtre.", null=True),
        ),
    ]
