#tdbmd-map {
    width: 100%;
    height: 75vh;
    position: relative;
    border: 1px solid var(--border-default-grey);
}
#tdbmd-map[fullscreen] {
    width: calc(100vw - 4rem);
    height: 90vh;
}
#tdbmd-map-legend {
    position: absolute;
    bottom: 10px;
    left: 10px;
    padding: 12px 22px 8px 16px;
    background-color: white;
    border-radius: 8px;
    opacity: 94%;
    display: flex;
    flex-direction: row;
    align-items: start;
    gap: 16px;
    border: 1px solid var(--border-default-grey);
    font-size: 0.8rem;
}
#tdbmd-map-legend.tdbmd-map-legend--small {
    cursor: pointer;
    padding: 8px 16px;
}
.tdbmd-map-legend--close {
    position: absolute;
    width: 24px;
    height: 24px;
    cursor: pointer;
    top: 2px;
    right: 2px;
}
.tdbmd-map-legend--close > svg {
    width: 18px;
    height: 18px;
    position: absolute;
    top: 2px;
    right: 2px;
}
#tdbmd-map-legend .tdbmd-map-legend-category {
    display: flex;
    flex-direction: row;
    align-items: center;
    gap: 8px;
    font-size: 0.8rem;
}
#tdbmd-map-legend .tdbmd-map-legend-category > div:first-child {
    width: 32px;
    height: 16px;
}

.gf-legend-line {
    display: flex;
    flex-direction: row;
    align-items: center;
}

.gf-legend-icon {
    width: 20px;
    display: inline-block;
    margin-right: 8px;
}

.gf-legend-color {
    width: 20px;
    height: 12px;
    margin-right: 8px;
}

.legend-section-title {
    font-weight: 600;
    margin-bottom: 4px;
}

#map-sidebar {
    position: absolute;
    z-index: 2;
    right: -1px;
    width: 300px;
    height: 100%;
    transition: width ease-in-out 0.3s;
    border-left: 1px solid var(--border-default-grey);
    border-right: 1px solid var(--border-default-grey);
    background-color: white;
    opacity: 94%;
}
#map-sidebar .ms-container {
    width: 100%;
    height: 100%;
    overflow-x: hidden;
    overflow-y: scroll;
}
#map-sidebar .ms-body {
    width: 300px;
    height: 100%;
    padding: 16px;
    display: flex;
    flex-direction: column;
    gap: 32px;
}
#map-sidebar .sidebar-title {
    font-size: 1.2rem;
    font-weight: bold;
}
#map-sidebar .title {
    margin-bottom: 16px;
    font-size: 1rem;
    font-weight: bold;
}
#map-sidebar .territory-name {
    font-size: 0.8rem;
    font-style: italic;
}
#map-sidebar #collapse {
    position: absolute;
    left: -40px;
    top: 16px;
    width: 40px;
    height: 40px;
    background-color: white;
    color: var(--text-action-high-blue-france);
    border: 1px solid var(--border-default-grey);
    cursor: pointer;
}
#map-sidebar #collapse span:before {
    transform: scaleX(-1);
}
#map-sidebar #collapse:hover {
    background-color: var(--grey-1000-50-hover);
}
#map-sidebar #collapse:focus {
    outline-offset: 2px;
    outline: 2px solid #fcc63a;
    background-color: #fef5e8;
    border: 1px dashed gray;
}
#map-sidebar .loader {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 16px;
}
#map-sidebar .spinner {
    color: #465f9d;
    animation: spin 1s linear infinite;
}
#map-sidebar .spinner circle {
    stroke-dasharray: 100;
    stroke-dashoffset: 0;
}
@keyframes spin {
    100% {
        transform: rotate(360deg);
    }
}
#map-sidebar .geo-feature-count {
    display: flex;
    gap: 8px;
    align-items: center;
}
#map-sidebar .filterTitle {
    font-size: 13px;
    padding-left: 14px;
    margin-top: 4px;
    margin-bottom: 16px;
}
#map-sidebar[data-open="false"] {
    width: 0px;
}
#map-sidebar[data-open="false"] #collapse {
    display: none;
}
#layers-checkboxes-legend {
    font-weight: bold;
}
.sidebar-filters label {
    font-size: 0.8rem;
}
#map-buttons {
    position: absolute;
    z-index: 1;
    top: 8px;
    left: 8px;
    display: flex;
    flex-direction: column;
    gap: 8px;
}
#map-buttons .map-button {
    border: 1px solid var(--border-default-grey);
    background-color: white;
    color: var(--text-action-high-blue-france);
    opacity: 94%;
    width: 32px;
    height: 32px;
    cursor: pointer;
    display: flex;
    justify-content: center;
    align-items: center;
}
#map-buttons .map-button:hover {
    background-color: var(--grey-1000-50-hover);
}
#map-buttons .map-button:focus {
    outline-offset: 2px;
    outline: 2px solid #fcc63a;
    background-color: #fef5e8;
    border: 1px dashed gray;
}
#map-download-buttons {
    margin-top: 24px;
    display: flex;
    flex-wrap: wrap;
    gap: 16px;
}
.mapboxgl-ctrl-logo {
    display: none !important;
}
#deckgl-wrapper:focus {
    outline: 2px solid #0a76f6 !important;
}
.table-geo-filters {
    display: flex;
    flex-direction: column;
    gap: 8px;
    padding-bottom: 64px;
}

.table-geo-filters {
    font-size: 0.9rem;
}

.table-geo-filters:has(details[open]) {
    padding-bottom: 300px;
}

.table-geo-filters input,
.table-geo-filters select {
    padding: 4px 8px;
    max-width: 250px;
    margin-top: 0px !important;
}

.table-geo-filters input[type="number"] {
    max-width: 70px;
}

.table-geo-filters label,
.table-geo-filters i {
    font-size: 0.8rem;
}

.table-geo-filters-details-body {
    margin-top: 8px;
    margin-bottom: 8px;
}
.reset-filters {
    text-decoration: underline;
    color: var(--text-action-high-blue-france);
    font-size: 0.8rem;
    cursor: pointer;
}
.reset-filters::before {
    content: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24' fill='%23000091'%3E%3Cpath d='M6.92893 0.514648L21.0711 14.6568L19.6569 16.071L15.834 12.2486L14 14.9999V21.9999H10V14.9999L4 5.99993H3V3.99993L7.585 3.99965L5.51472 1.92886L6.92893 0.514648ZM21 3.99993V5.99993H20L18.085 8.87193L13.213 3.99993H21Z'%3E%3C/path%3E%3C/svg%3E");
    width: 16px;
    display: inline-block;
    margin-right: 4px;
    transform: translateY(2px);
}
.no-filters {
    font-size: 0.8rem;
}
.no-filters::before {
    content: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24' fill='%233a3a3a'%3E%3Cpath d='M21 4V6H20L15 13.5V22H9V13.5L4 6H3V4H21ZM6.4037 6L11 12.8944V20H13V12.8944L17.5963 6H6.4037Z'%3E%3C/path%3E%3C/svg%3E");
    width: 16px;
    display: inline-block;
    margin-right: 4px;
    transform: translateY(2px);
}
.geo-filters-numbers-col {
    display: flex;
    flex-direction: column;
    gap: 8px;
}

.geo-filters-numbers-row {
    display: flex;
    flex-direction: row;
    gap: 32px;
}
.react-datepicker__input-container input {
    border-color: hsl(0, 0%, 80%);
    border-radius: 4px;
    border-style: solid;
    border-width: 1px;
    width: 95px;
}

.date-pickers-range {
    display: flex;
    flex-direction: row;
    gap: 32px;
}

.react-datepicker__header {
    background-color: #ececfe !important;
}

.react-datepicker__header h2 {
    padding: 0px !important;
}

.react-datepicker__header__dropdown {
    padding-bottom: 16px !important;
}

.react-datepicker__close-icon:hover {
    background-color: inherit !important;
}

.react-select__menu {
    font-size: 0.8rem !important;
}

.react-select__option {
    padding: 4px 12px !important;
}
.filters-title {
    margin-top: 16px;
}

#map-help-details {
    margin-top: 8px;
    font-size: 0.9rem;
}

#map-help-details p {
    font-size: 0.9rem;
}

#map-help-details-summary {
    font-size: 0.8rem;
}
#map-loader {
    position: absolute;
    bottom: 8px;
    right: 8px;
    font-size: 0.6rem;
    background-color: rgba(255, 255, 255, 0.9);
    padding: 8px 16px 0px 16px;
    border-radius: 4px;
}
