<button 
    class="fr-btn--tooltip fr-btn fr-btn--sm fr-icon-link fr-btn--tertiary-no-outline anchor-link" 
    title="copier le lien"
    data-anchor="{{anchor}}"
    type="button"
    aria-describedby="copy-tooltip-{{anchor}}"
    {% if indicator %}
        data-indicator="{{ indicator.name }}"
        data-track="true"
    {% endif %}
></button>
<span class="fr-tooltip fr-placement" id="copy-tooltip-{{anchor}}" role="tooltip">
    Lien copié
</span>