# Generated by Django 5.2.10 on 2026-01-19 15:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geo_lib', '0003_geofeature_color_column_geofeature_size_column'),
    ]

    operations = [
        migrations.AddField(
            model_name='geofeature',
            name='legend',
            field=models.TextField(blank=True, help_text='Si les points sur la carte ont une couleur ou une taille différente par point, veuillez indiquer une légende dans ce champ.<br/>\n        Le format est le suivant :<br/>\n        <ul>\n            <li>\n                Chaque ligne correspond à une ligne de la légende.\n            </li>\n            <li>\n                Vous pouvez commencez une ligne avec un icone du point selon une couleur et une taille précise.<br/>\n                Dans ce cas commencez la ligne par le format suivant : "icone(couleur:#000000,taille:sm)"<br/>\n                Utilisez un code couleur hexadécimal, ou bien "couleur:nulle" pour ne pas mettre de couleur.<br/>\n                Les deux valeurs possibles pour la taille sont : "sm" et "md".<br/>\n                <i>Exemple:</i> "icone(couleur:nulle,taille:md) Stationnement avec capacité > 20 places"\n            </li>\n            <li>\n                Vous pouvez commencer une ligne par un carré de couleur.<br/>\n                Le format est : "couleur(#000000)"<br/>\n                <i>Exemple</i> "couleur(#ff00ff) Stationnement payant"\n            </li>\n        </ul>', null=True, verbose_name='Légende'),
        ),
    ]
