from django.urls import path

from territories_dashboard_lib.website_lib.views.api import (
    left_menu_view,
)

app_name = "website-api"

urlpatterns = [
    path("left-menu/<str:theme_name>/", left_menu_view, name="left-menu"),
]
