from django.contrib.auth import get_user_model

DefaultUserModel = get_user_model()


class ProxyUser(DefaultUserModel):
    class Meta:
        proxy = True

    @property
    def has_favorite_indicators(self):
        return self.favorite_indicators.exists()
