# Generated by Django 5.2.11 on 2026-02-04 18:23

import django.db.models.deletion
import martor.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('indicators_lib', '0006_indicator_hidden'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='subtheme',
            name='description',
        ),
        migrations.AlterField(
            model_name='filter',
            name='color',
            field=models.TextField(blank=True, help_text='format hexadécimale : #FF11DD. Les données associées à ce filtre apparaitront de cette couleur dans les graphiques.', null=True, verbose_name='Couleur'),
        ),
        migrations.AlterField(
            model_name='filter',
            name='db_name',
            field=models.CharField(max_length=128, verbose_name='Nom dans la BDD'),
        ),
        migrations.AlterField(
            model_name='filter',
            name='default',
            field=models.BooleanField(default=True, verbose_name='Sélectionné par défaut ?'),
        ),
        migrations.AlterField(
            model_name='filter',
            name='order',
            field=models.IntegerField(default=0, help_text="L'ordre démarre à 0.", verbose_name='Ordre'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='aggregation_constant',
            field=models.DecimalField(decimal_places=5, default=1, max_digits=10, verbose_name="Constante d'agrégation"),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='aggregation_function',
            field=models.CharField(choices=[('discrete', 'Discrete Component 2'), ('repeated', 'Repeated Component 2')], default='repeated', max_length=8, verbose_name="Fonction d'agrégation"),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='db_table_prefix',
            field=models.CharField(help_text='Attention, le nom doit être exactement le même que celui en base.', max_length=128, verbose_name='Préfixe dans la DB'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='flows_db_table_prefix',
            field=models.CharField(blank=True, help_text='Uniquement pour les indicateurs de flux. Nom de la table des flux.', max_length=128, null=True, verbose_name='Table des flux (prefix)'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='flows_dimension',
            field=models.CharField(blank=True, help_text='Uniquement pour les indicateurs de flux. Nom de la colonne de dimension dans la table des flux.', max_length=32, null=True, verbose_name='Dimension des flux'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='index_in_theme',
            field=models.IntegerField(default=0, help_text="L'ordre démarre à 0.", verbose_name='Ordre sous-thème'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='is_active',
            field=models.BooleanField(default=True, verbose_name='Actif ?'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='is_composite',
            field=models.BooleanField(default=False, verbose_name='Indicateur composite'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='methodo',
            field=martor.models.MartorField(blank=True, default='', verbose_name='Méthodologie (markdown)'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='name',
            field=models.CharField(help_text="Pour l'URL, ne mettre que des lettres minuscules sans accents et des tirets.", max_length=32, unique=True, verbose_name='Nom (~id, URL)'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='secondary_indicator',
            field=models.ForeignKey(blank=True, help_text='Optionnel.', null=True, on_delete=django.db.models.deletion.SET_NULL, to='indicators_lib.indicator', verbose_name='Second indicateur à afficher sur la carte'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='short_title',
            field=models.CharField(blank=True, help_text='Utilisé pour les popups et la légende de la carte.', max_length=128, null=True, verbose_name='Titre abrégé'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='show_alternative',
            field=models.BooleanField(default=True, help_text="Pour certains indicateurs, il n'y a pas de valeur alternative à afficher.", verbose_name='Afficher la valeur alternative'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='show_evolution',
            field=models.BooleanField(default=True, verbose_name="Activer l'historique"),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='sub_theme',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='indicators', to='indicators_lib.subtheme', verbose_name='Sous-thème'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='title',
            field=models.CharField(max_length=128, verbose_name='Titre (affiché)'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='unite',
            field=models.CharField(max_length=32, verbose_name='Unité (affichée)'),
        ),
        migrations.AlterField(
            model_name='indicator',
            name='unite_alternative',
            field=models.CharField(blank=True, default=None, max_length=32, null=True, verbose_name='Unité alternative (affichée)'),
        ),
        migrations.AlterField(
            model_name='subtheme',
            name='index_in_theme',
            field=models.IntegerField(default=0, help_text="L'ordre démarre à 0.", verbose_name='Ordre thème'),
        ),
        migrations.AlterField(
            model_name='subtheme',
            name='name',
            field=models.CharField(help_text="Pour l'URL, ne mettre que des lettres minuscules sans accents et des tirets.", max_length=64, unique=True, verbose_name='Nom (~id, URL)'),
        ),
        migrations.AlterField(
            model_name='subtheme',
            name='theme',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='sub_themes', to='indicators_lib.theme', verbose_name='Thème'),
        ),
        migrations.AlterField(
            model_name='subtheme',
            name='title',
            field=models.CharField(max_length=128, verbose_name='Titre (affiché)'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='action_theme',
            field=models.TextField(blank=True, verbose_name='Actions'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='name',
            field=models.CharField(help_text="Pour l'URL, ne mettre que des lettres minuscules sans accents et des tirets.", max_length=64, unique=True, verbose_name='Nom (~id, URL)'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='objectif_theme',
            field=models.TextField(blank=True, verbose_name='Objectif'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='ordering',
            field=models.IntegerField(default=0, help_text="L'ordre démarre à 0.", verbose_name='Ordre dans la sidebar'),
        ),
        migrations.AlterField(
            model_name='theme',
            name='title',
            field=models.CharField(max_length=128, verbose_name='Titre (affiché)'),
        ),
    ]
