# Generated by Django 5.2.11 on 2026-02-10 16:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('superset_lib', '0003_alter_dashboard_order_alter_filter_mesh_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='filter',
            name='mesh',
            field=models.TextField(blank=True, choices=[('fr', 'Fr'), ('reg', 'Reg'), ('dep', 'Dep'), ('epci', 'Epci'), ('com', 'Com'), ('aom', 'Aom'), ('ept', 'Ept')], help_text="Maille pour laquelle s'effectue le filtre sur le territoire.", null=True),
        ),
    ]
