# Generated by Django 5.2.9 on 2026-01-06 16:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tracking_lib', '0005_alter_page_cmp_territory_mesh_alter_page_submesh_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='event',
            name='name',
            field=models.TextField(choices=[('download', 'Download'), ('vue-resume-indicateur', 'View Indicator Card')]),
        ),
    ]
