{% if request.user.is_authenticated %}
    <form style="display:inline;">
        {% csrf_token %}
        <button
            title="Déplacer l'indicateur vers le haut"
            type="button"
            class="card-order-up fr-btn fr-btn--tertiary-no-outline fr-btn--sm fr-icon-arrow-up-line"
            onclick="orderFavorite(this)"
        ></button>
        <button
            title="Déplacer l'indicateur vers le bas"
            type="button"
            class="card-order-down fr-btn fr-btn--tertiary-no-outline fr-btn--sm fr-icon-arrow-down-line"
            onclick="orderFavorite(this)"
        ></button>
    </form>
{% endif %}