<ul id="thematics-links">
    {% for theme in themes %}
        <li>
            <a href="{% if comparison %}{% url 'website:comparison' theme_name=theme.name %}{% else %}{% url 'website:theme' theme_name=theme.name %}{% endif %}">
                {{ theme.title }}
            </a>
        </li>
    {% endfor %}
</ul>
