.new-notification-round {
    position: absolute;
    width: 10px;
    height: 10px;
    border-radius: 50%;
    background-color: rgb(106, 106, 244);
    animation: radiate 2.4s ease-out 3;
    position: absolute;
    top: calc(50% - 5px);
    right: 16px;
    z-index: 1;
}

@keyframes radiate {
    0% {
        box-shadow:
            0 0 0 0 rgba(106, 106, 244, 0.6),
            0 0 0 0 rgba(106, 106, 244, 0.4),
            0 0 0 0 rgba(106, 106, 244, 0.2);
    }
    60% {
        box-shadow:
            0 0 0 8px rgba(106, 106, 244, 0),
            0 0 0 14px rgba(106, 106, 244, 0),
            0 0 0 20px rgba(106, 106, 244, 0);
    }
    100% {
        box-shadow:
            0 0 0 8px rgba(106, 106, 244, 0),
            0 0 0 14px rgba(106, 106, 244, 0),
            0 0 0 20px rgba(106, 106, 244, 0);
    }
}

.left-menu-items {
    position: relative;
}

#left-menu-sticky-container {
    height: 100%;
    position: relative;
}

#left-menu-sticky-element {
    position: sticky;
    top: 0px;
    padding: 16px 0px;
}

#left-menu-sticky-element.is-stuck {
    max-height: 100vh;
    overflow: scroll;
}

#left-menu-top-sentinel,
#left-menu-bottom-sentinel {
    width: 1px;
    height: 1px;
}

#left-menu-bottom-sentinel {
    position: absolute;
    bottom: 0px;
}
