# Generated by Django 5.2.11 on 2026-02-10 16:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('tracking_lib', '0007_alter_event_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='page',
            name='cmp_territory_mesh',
            field=models.TextField(blank=True, choices=[('fr', 'Fr'), ('reg', 'Reg'), ('dep', 'Dep'), ('epci', 'Epci'), ('com', 'Com'), ('aom', 'Aom'), ('ept', 'Ept')], help_text="Maille du territoire de comparaison, null s'il ne s'agit pas de la page comparaison.", null=True),
        ),
        migrations.AlterField(
            model_name='page',
            name='submesh',
            field=models.TextField(blank=True, choices=[('fr', 'Fr'), ('reg', 'Reg'), ('dep', 'Dep'), ('epci', 'Epci'), ('com', 'Com'), ('aom', 'Aom'), ('ept', 'Ept')], help_text="Maille d'analyse sélectionnée.", null=True),
        ),
        migrations.AlterField(
            model_name='page',
            name='territory_mesh',
            field=models.TextField(blank=True, choices=[('fr', 'Fr'), ('reg', 'Reg'), ('dep', 'Dep'), ('epci', 'Epci'), ('com', 'Com'), ('aom', 'Aom'), ('ept', 'Ept')], help_text='Maille du territoire principal sélectionné.', null=True),
        ),
    ]
