{% load other_filters %}

{% if params.mesh != params.territory_mesh and params|should_mesh_analysis:indicator %}
    <section class="tdbmd-indicator-card__comparisons fr-grid-row fr-grid-row--gutters">
        <h4 class="fr-sr-only">Statistiques</h4>
        {% include "./extremum.html" with title="Minimum" prefix="min" %}
        {% include "./extremum.html" with title="Mediane" prefix="med" %}
        {% include "./extremum.html" with title="Maximum" prefix="max" %}
    </section>
{% else %}
    <div>Les statistiques ne sont pas disponibles à cette maille.</div>
{% endif %}
