# Generated by Django 5.2.11 on 2026-02-04 18:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('superset_lib', '0002_alter_filter_mesh'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dashboard',
            name='order',
            field=models.IntegerField(default=0, help_text="Numéro d'ordre dans la dropdown de sélection, les dashboards sont triés du plus petit numéro au plus grand. L'ordre démarre à 0.", verbose_name="Numéro d'ordre"),
        ),
        migrations.AlterField(
            model_name='filter',
            name='mesh',
            field=models.TextField(blank=True, choices=[('fr', 'Fr'), ('reg', 'Reg'), ('dep', 'Dep'), ('epci', 'Epci'), ('com', 'Com'), ('aom', 'Aom')], help_text="Maille pour laquelle s'effectue le filtre sur le territoire.", null=True),
        ),
        migrations.AlterField(
            model_name='filter',
            name='superset_col',
            field=models.TextField(blank=True, help_text="Nom de la colonne en base de données liée au filtre sur le territoire et utilisé dans Superset. Pour trouver le nom, on peut faire les mêmes étapes que pour le 'superset_id' et chercher 'column' dans les paramètres json du native filter.", null=True),
        ),
        migrations.AlterField(
            model_name='filter',
            name='superset_id',
            field=models.TextField(blank=True, help_text="ID du native filter du territoire, qui permettra d'initialiser les filtres du dasbhoard selon le territoire sélectionné dans l'application. Pour le récupérer c'est un petit parcours du combattant : aller sur le dashboard dans superset, cliquer sur modifier le dashboard, cliquer sur les trois petits points, puis sur modifier les propriétés. Cliquer sur avancé, copier le json et le coller dans un site comme : https://jsonformatter.curiousconcept.com/ pour mieux le voir. Chercher 'global_chart_configuration' puis 'native_filter_configuration'. Chercher le native filter lié au choix du territoire. Copier l'id qui dans son nom, le nom est de la forme NATIVE_FILTER-ID. ", null=True),
        ),
    ]
