{% if request.user.is_authenticated %}
    <form style="display:inline;">
        {% csrf_token %}
        <button
            title="{% if is_favorite %}retirer des favoris{% else %}ajouter en favori{% endif %}"
            type="button"
            class="fr-btn fr-btn--tertiary-no-outline fr-btn--sm {% if is_favorite %}fr-icon-star-fill{% else %}fr-icon-star-line{% endif %}"
            onclick="toggleFavorite(this)"
        ></button>
    </form>
{% endif %}