html[data-theme="light"],
:root {
    --primary: #79c879;
    --secondary: #419041;
    --accent: #f5dd5d;
    --primary-fg: #fff;

    --body-fg: #333;
    --body-bg: #fff;
    --body-quiet-color: #666;
    --body-medium-color: #444;
    --body-loud-color: #000;

    --header-color: #ffc;

    --breadcrumbs-fg: #c4e8c4;
    --breadcrumbs-bg: #265d26;

    --link-fg: #419341;
    --link-hover-color: #006300;

    --hairline-color: #e8e8e8;
    --border-color: #ccc;

    --error-fg: #ba2121;

    --message-success-bg: #dfd;
    --message-warning-bg: #ffc;
    --message-error-bg: #ffefef;

    --darkened-bg: #f8f8f8; /* A bit darker than --body-bg */
    --selected-bg: #e4e4e4; /* E.g. selected table cells */
    --selected-row: #ffc;

    --button-fg: #fff;
    --button-hover-bg: #206720;
    --default-button-bg: #206720;
    --close-button-bg: #747474;
    --close-button-hover-bg: #333;
    --delete-button-bg: #ba2121;
    --delete-button-hover-bg: #a41515;
}

@media (prefers-color-scheme: dark) {
    :root {
        --primary: #265d26;
        --primary-fg: #f7f7f7;

        --body-fg: #eeeeee;
        --body-bg: #121212;
        --body-quiet-color: #d0d0d0;
        --body-medium-color: #e0e0e0;
        --body-loud-color: #ffffff;

        --breadcrumbs-link-fg: #e0e0e0;
        --breadcrumbs-bg: var(--primary);

        --link-fg: #81fa81;
        --link-hover-color: #4af74a;
        --link-selected-fg: #6fc66f;

        --hairline-color: #272727;
        --border-color: #353535;

        --error-fg: #e35f5f;
        --message-success-bg: #006b1b;
        --message-warning-bg: #583305;
        --message-error-bg: #570808;

        --darkened-bg: #212121;
        --selected-bg: #1b1b1b;
        --selected-row: #003a00;

        --close-button-bg: #333333;
        --close-button-hover-bg: #666666;

        color-scheme: dark;
    }
}

html[data-theme="dark"] {
    --primary: #265d26;
    --primary-fg: #f7f7f7;

    --body-fg: #eeeeee;
    --body-bg: #121212;
    --body-quiet-color: #d0d0d0;
    --body-medium-color: #e0e0e0;
    --body-loud-color: #ffffff;

    --breadcrumbs-link-fg: #e0e0e0;
    --breadcrumbs-bg: var(--primary);

    --link-fg: #81fa81;
    --link-hover-color: #4af74a;
    --link-selected-fg: #6fc66f;

    --hairline-color: #272727;
    --border-color: #353535;

    --error-fg: #e35f5f;
    --message-success-bg: #006b1b;
    --message-warning-bg: #583305;
    --message-error-bg: #570808;

    --darkened-bg: #212121;
    --selected-bg: #1b1b1b;
    --selected-row: #003a00;

    --close-button-bg: #333333;
    --close-button-hover-bg: #666666;

    color-scheme: dark;
}
