# Generated by Django 5.2.10 on 2026-01-20 10:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('indicators_lib', '0005_auto_20251203_1621'),
    ]

    operations = [
        migrations.AddField(
            model_name='indicator',
            name='hidden',
            field=models.BooleanField(default=False, help_text="Coché pour cacher un indicateur actif, il pourra être utilisé en tant que second indicateur sur la carte mais il n'apparaitra pas dans la liste des indicateurs", verbose_name='Caché'),
        ),
    ]
