{% load other_filters %}

{% if params|should_mesh_analysis:indicator %}
    <div class="subtheme" id="values-table-section">
        <div class="fr-px-md-4w fr-px-2w fr-py-2w">
            <h3 class="fr-mt-4w">Tableau des valeurs de l'indicateur</h3>
            <div class="data-table" data-source="indicator"></div>
        </div>
    </div>
{% else %}
    <div class="subtheme">
        <div class="fr-px-md-4w fr-px-2w fr-py-2w">
            <h3 class="fr-mt-4w">Tableau des valeurs de l'indicateur</h3>
            <div>Le tableau n'est pas disponible pour la maille sélectionnée.</div>
        </div>
    </div>
{% endif %}
