# Generated by Django 5.2.11 on 2026-02-04 18:23

import martor.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('website_lib', '0005_mainconf_meshes'),
    ]

    operations = [
        migrations.AlterField(
            model_name='landingpage',
            name='body',
            field=martor.models.MartorField(help_text="Contenu de la page d'accueil au format Markdown pour la page d'accueil par défaut.", verbose_name='Contenu'),
        ),
        migrations.AlterField(
            model_name='landingpage',
            name='button_link',
            field=models.TextField(help_text="Lien du bouton d'action de la page d'accueil (pour la page d'accueil par défaut), au format markdown, par exemple : [découvrir les indicateurs](/indicateurs/)", verbose_name='Lien du bouton'),
        ),
        migrations.AlterField(
            model_name='mainconf',
            name='contact_email',
            field=models.TextField(blank=True, default=None, help_text="Uniquement si l'affichage de la bannière d'email de contact et d'inscription à la newsletter est activée.", null=True, verbose_name='Email de contact'),
        ),
        migrations.AlterField(
            model_name='mainconf',
            name='footer_navigation',
            field=models.TextField(default='', help_text='Navigation du footer (bas de page).\nMettre les liens au format markdown, un par ligne.\n\nSi le lien est interne, commencer et terminer le lien par un slash comme "/accueil/"\n\nPar exemple :\n\n[Plan du site](/plan-site/)\n[Accessibilité](/accessibilite/)\n[Mentions légales](/mentions-legales/)', verbose_name='Navigation du footer'),
        ),
        migrations.AlterField(
            model_name='mainconf',
            name='header_navigation',
            field=models.TextField(default='', help_text='Navigation du header (liste des onglets et sous-onglets en haut de page).\nMettre les liens au format markdown avec un slash à la fin du lien, mettre une ligne vide entre chaque rubrique.\n        \nUne rubrique peut contenir un seul lien, ou bien plusieurs, dans ce cas la rubrique sera sous forme de dropdown et il faut mettre un titre en premier. \n\nPar exemple : \n\n[Accueil](/accueil/)\n\n[Indicateurs territoriaux](/indicateurs/)\n\nÀ propos\n[Présentation](/presentation/)\n[Journal des versions](/journal/)', verbose_name='Navigation du header'),
        ),
        migrations.AlterField(
            model_name='mainconf',
            name='newsletter_link',
            field=models.TextField(blank=True, default=None, help_text="Uniquement si l'affichage de la bannière d'email de contact et d'inscription à la newsletter est activée.", null=True, verbose_name="Lien d'inscription à la newsletter"),
        ),
        migrations.AlterField(
            model_name='noticebanner',
            name='description',
            field=models.CharField(help_text='Texte à afficher dans la bannière à la suite du Titre.', max_length=255, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='noticebanner',
            name='link_href',
            field=models.CharField(blank=True, help_text="Optionnel. Le lien doit être un lien interne et commencer et terminer par '/', par exemple '/journal/'", max_length=255, null=True, verbose_name='Lien'),
        ),
        migrations.AlterField(
            model_name='noticebanner',
            name='link_text',
            field=models.CharField(blank=True, help_text='Optionnel. A remplir seulement si un lien est spécifié', max_length=64, null=True, verbose_name='Intitulé du lien'),
        ),
        migrations.AlterField(
            model_name='noticebanner',
            name='title',
            field=models.CharField(help_text='Sera affiché en gras au début de la bannière.', max_length=64, verbose_name='Titre'),
        ),
    ]
