{% load other_filters %}

{% with is_favorite=indicator.id|is_in:favorite_indicators_ids %}
    {% include "territories_dashboard_lib/website/pages/indicators/components/favorite.html" %}
{% endwith %}

{% if theme.name == "favoris" %}
    {% include "territories_dashboard_lib/website/pages/indicators/components/favorite-order.html" %}
{% endif %}

{% include "territories_dashboard_lib/website/pages/indicators/components/anchor.html" with anchor=indicator.name indicator=indicator only %}