{% if indicator.flows_db_table_prefix %}
    <div class="subtheme">
        <div class="fr-px-md-4w fr-px-2w fr-py-2w">
            <h3 class="fr-mt-4w">Tableau des flux</h3>
            <div class="data-table" data-source="flows"></div>
        </div>
    </div>
{% endif %}