 {% extends "territories_dashboard_lib/website/layout/base.html" %}

{% load static %}
{% load other_filters %}

{% block page_title %}Méthodologie : {{indicator.title}}{% endblock %}

{% block extra_head %}
    {{ indicator|json_script:"indicator-js" }}
    <script>{% include "./methodo.js" %}</script>
{% endblock %}

{% block main %}
    <div class="fr-container fr-pt-5w fr-pb-10w">
        <nav role="navigation" class="fr-breadcrumb" aria-label="vous êtes ici :">
            <button class="fr-breadcrumb__button" aria-expanded="false" aria-controls="breadcrumb-1">Voir le fil d’Ariane</button>
            <div class="fr-collapse" id="breadcrumb-1">
                <ol class="fr-breadcrumb__list">
                    <li>
                        <a class="fr-breadcrumb__link" href="/">Accueil</a>
                    </li>
                    <li>
                        <a class="fr-breadcrumb__link" href="{% url 'website:theme' theme_name=theme.name %}">{{theme.title}}</a>
                    </li>
                    <li>
                        <a class="fr-breadcrumb__link" href="{% url 'website:indicator-details' indicator_name=indicator.name %}">{{indicator.title}}</a>
                    </li>
                    <li>
                        <a class="fr-breadcrumb__link" aria-current="page">Méthodologie</a>
                    </li>
                </ol>
            </div>
        </nav>
        <h1>Fiche méthodologique : {{ indicator.title }}</h1>
        <p>Thématique : {{ indicator.theme }}</p>
        <button class="methodo-export-button fr-btn fr-btn--secondary fr-btn--sm fr-icon-file-pdf-line fr-btn--icon-right   fr-mb-4w">Exporter la fiche méthodologique</button>
        <div class="tdbmd-markdown">{{ indicator.methodo_html | safe }}</div>
        <button class="methodo-export-button fr-btn fr-btn--secondary fr-btn--sm fr-icon-file-pdf-line fr-btn--icon-right">Exporter la fiche méthodologique</button>
    </div>
{% endblock %}
