# Generated by Django 5.2.11 on 2026-02-10 16:00

import django.contrib.postgres.fields
import territories_dashboard_lib.website_lib.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('website_lib', '0006_alter_landingpage_body_alter_landingpage_button_link_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mainconf',
            name='footer_navigation',
            field=models.TextField(default='', help_text='Navigation du footer (bas de page).<br/><br/>\n\nMettre les liens au format markdown, un par ligne.<br/><br/>\n\nSi le lien est interne, commencer et terminer le lien par un slash comme "/accueil/"<br/><br/>\n\nPar exemple :<br/><br/>\n\n[Plan du site](/plan-site/)<br/>\n[Accessibilité](/accessibilite/)<br/>\n[Mentions légales](/mentions-legales/)', verbose_name='Navigation du footer'),
        ),
        migrations.AlterField(
            model_name='mainconf',
            name='header_navigation',
            field=models.TextField(default='', help_text='Navigation du header (liste des onglets et sous-onglets en haut de page).<br/><br/>\n\nMettre les liens au format markdown avec un slash à la fin du lien, mettre une ligne vide entre chaque rubrique.<br/><br/>\n        \nUne rubrique peut contenir un seul lien, ou bien plusieurs, dans ce cas la rubrique sera sous forme de dropdown et il faut mettre un titre en premier.<br/><br/>\n\nPar exemple :<br/><br/>\n\n[Accueil](/accueil/)<br/><br/>\n\n[Indicateurs territoriaux](/indicateurs/)<br/><br/>\n\nÀ propos<br/>\n[Présentation](/presentation/)<br/>\n[Journal des versions](/journal/).\n', verbose_name='Navigation du header'),
        ),
        migrations.AlterField(
            model_name='mainconf',
            name='meshes',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.TextField(choices=[('fr', 'Fr'), ('reg', 'Reg'), ('dep', 'Dep'), ('epci', 'Epci'), ('com', 'Com'), ('aom', 'Aom'), ('ept', 'Ept')]), default=territories_dashboard_lib.website_lib.models.get_default_meshes, help_text="Liste des mailles territoriales activées sur la plateforme, la liste des mailles disponible est : ['fr', 'reg', 'dep', 'epci', 'com', 'aom', 'ept'].<br/>L'ajout de nouvelles mailles demande une modification de la base de données des indicateurs ainsi que du code.", size=None, verbose_name='Mailles'),
        ),
    ]
