from territories_dashboard_lib.indicators_lib.models import Theme


def get_favorite_theme():
    return Theme(name="favoris", title="Indicateurs favoris")


def get_favorite_subtheme(indicators):
    return {
        "name": "tableau-de-bord",
        "title": "Mon tableau de bord",
        "indicators": indicators,
    }
