.staticPage .code {
    background-color: #ececfe;
    font-family: inherit;
    padding: 0 4px;
    border-radius: 4px;
    font-size: smaller;
    font-style: normal;
}

.staticPage table {
    width: 100%;
    border-collapse: collapse;
}

.staticPage table th,
.staticPage table td {
    padding: 8px 16px;
    text-align: left;
}

.staticPage caption {
    font-weight: bold;
    text-align: left;
    margin-bottom: 16px;
}

.staticPage tbody td:first-child {
    font-weight: bold;
}
