# Generated by Django 5.2.11 on 2026-02-04 18:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geo_lib', '0004_geofeature_legend'),
    ]

    operations = [
        migrations.AlterField(
            model_name='geoelement',
            name='filterable',
            field=models.BooleanField(default=True, help_text="Si coché, l'attribut est filtrable par l'utilisateur dans le volet de gestion des filtres.", verbose_name='Filtrable'),
        ),
        migrations.AlterField(
            model_name='geoelement',
            name='linked_to_indicator',
            field=models.BooleanField(default=False, help_text="Si coché, le filtre de l'indicateur avec le même nom sera relié au filtre de la carte.", verbose_name="Relié aux filtres de l'indicateur"),
        ),
        migrations.AlterField(
            model_name='geofeature',
            name='color',
            field=models.TextField(default='#000000', help_text="Couleur des données sur la carte, à renseigner au format hexadécimal, par exemple: '#05B2F9'", verbose_name='Couleur'),
        ),
        migrations.AlterField(
            model_name='geofeature',
            name='name',
            field=models.TextField(help_text='Attention, le nom doit être exactement le même que celui en base.', verbose_name='Nom de la table en base'),
        ),
        migrations.AlterField(
            model_name='geofeature',
            name='point_icon_svg',
            field=models.TextField(blank=True, help_text="Icone SVG à utiliser pour les points.<br/>Laisser vide pour les autres types de géométrie.<br/>Veuillez charger un fichier provenant des <a href='https://fonts.google.com/icons'>Material Icons</a> de Google.", null=True, verbose_name='Icone des points'),
        ),
        migrations.AlterField(
            model_name='geofeature',
            name='show_on_fr_level',
            field=models.BooleanField(default=True, help_text='Décochez si la quantité de données est trop importante pour le niveau France.', verbose_name='Afficher au niveau France'),
        ),
    ]
